@@ -5,6 +5,7 @@ from django.templatetags.static import static
 from django.utils.translation import get_language
 
 from ephios.extra.signals import footer_link
+from ephios.settings import SITE_URL
 
 try:
     EPHIOS_VERSION = (
@@ -29,4 +30,5 @@ def ephios_base_context(request):
         "footer": footer,
         "datatables_translation_url": datatables_translation_url,
         "ephios_version": EPHIOS_VERSION,
+        "SITE_URL": SITE_URL,
     }
